Description Usage Arguments Value Source Examples
View source: R/cfb_team_roster.R
Team Roster Get a teams full roster by year. If team is not selected, API returns rosters for every team from the selected year.
1 | cfb_team_roster(year, team = NULL)
|
year |
(Integer required): Year, 4 digit format (YYYY) |
team |
(String optional): Team, select a valid team in D-I football |
A data frame with 12 variables:
athlete_idcharacter.
first_namecharacter.
last_namecharacter.
weightinteger.
heightinteger.
jerseyinteger.
yearinteger.
positioncharacter.
home_citycharacter.
home_statecharacter.
home_countrycharacter.
teamcharacter.
https://api.collegefootballdata.com/roster
1 | cfb_team_roster(year = 2013, team = "Florida State")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.